<?php

declare(strict_types=1);

namespace Drupal\simple_interactive_maps\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Url;
use Drupal\simple_interactive_maps\ClippableContent;
use Drupal\simple_interactive_maps\InteractiveMapInterface;
use Drupal\simple_interactive_maps\MapDataLoader;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpKernel\Exception\HttpException;

/**
 * Returns responses for Simple Interactive Maps routes.
 */
final class MapRegionController extends ControllerBase {

  /**
   * Builds the response.
   */
  public function __invoke(InteractiveMapInterface $interactive_map = NULL): array {
    if (!($interactive_map instanceof InteractiveMapInterface)) {
      throw new HttpException(404, 'Interactive map not found.');
    }

    $regions = $interactive_map->getRegions();

    $build = [];

    $build['table'] = [
      '#type' => 'table',
      '#header' => ['ID', 'Name', 'Group', 'Actions'],
    ];

    $rows = [];
    foreach ($regions as $id => $region) {
      $rows[$id] = [
        $id,
        $region['label'],
        $region['group'],
        [
          'data' => [
            '#type' => 'link',
            '#title' => $this->t('Edit'),
            '#url' => Url::fromRoute('simple_interactive_maps.region_edit', [
              'interactive_map' => $interactive_map->id(),
              'region_id' => $id,
            ], [
              'query' => [
                'destination' => Url::fromRoute('<current>')->toString(),
              ],
            ]),
          ],
        ],
      ];
    }

    $build['table']['#rows'] = $rows;

    return $build;
  }

}
